@@ -1,15 +1,18 @@
-VERSION = (2, 0, 2, 'final')
-if VERSION[-1] != "final":
+# -*- coding: utf-8 -*-
+VERSION = (2, 1, 1, 'final')
+if VERSION[-1] != "final": # pragma: no cover
     __version__ = '.'.join(map(str, VERSION))
-else:
+else: # pragma: no cover
     __version__ = '.'.join(map(str, VERSION[:-1]))
 
+
 # patch settings 
 try:
-    from conf import patch_settings
     from django.conf import settings
-    patch_settings()
-except ImportError:
+    if 'cms' in settings.INSTALLED_APPS:
+        from conf import patch_settings
+        patch_settings()
+except ImportError: # pragma: no cover
     """
     This exception means that either the application is being built, or is
     otherwise installed improperly. Both make running patch_settings
