@@ -1,4 +1,11 @@
-class PluginAllreadyRegistered(Exception):
+# -*- coding: utf-8 -*-
+class PluginAlreadyRegistered(Exception):
+    pass
+
+class PluginNotRegistered(Exception):
+    pass
+
+class AppAllreadyRegistered(Exception):
     pass
 
 class NotImplemented(Exception):
@@ -20,4 +27,8 @@ class PermissionsException(Exception):
 
 class NoPermissionsException(PermissionsException):
     """Can be fired when some violate action is performed on permission system. 
-    """
\ No newline at end of file
+    """
+    
+class DuplicatePlaceholderWarning(Warning): pass
+
+class DontUsePageAttributeWarning(Warning): pass
\ No newline at end of file
