@@ -1,27 +1,80 @@
+# -*- coding: utf-8 -*-
+from cms.models import CMSPlugin
+from cms.exceptions import SubClassNeededError
 from django.conf import settings
 from django.forms.models import ModelForm
 from django.utils.encoding import smart_str
 from django.contrib import admin
-from cms.models import CMSPlugin
-from cms.exceptions import SubClassNeededError
- 
+from django.forms.widgets import Media, MediaDefiningClass
+
+def pluginmedia_property(cls):
+    def _media(self):
+        # Get the plugin media property of the superclass, if it exists
+        if hasattr(super(cls, self), 'pluginmedia'):
+            base = super(cls, self).pluginmedia
+        else:
+            base = Media()
+
+        # Get the media definition for this class
+        definition = getattr(cls, 'PluginMedia', None)
+        if definition:
+            extend = getattr(definition, 'extend', True)
+            if extend:
+                if extend == True:
+                    m = base
+                else:
+                    m = Media()
+                    for medium in extend:
+                        m = m + base[medium]
+                return m + Media(definition)
+            else:
+                return Media(definition)
+        else:
+            return base
+    return property(_media)
+
+class PluginMediaDefiningClass(MediaDefiningClass):
+    def __new__(cls, name, bases, attrs):
+        new_class = super(PluginMediaDefiningClass, cls).__new__(cls, name, bases,
+                                                           attrs)
+        if 'pluginmedia' not in attrs:
+            new_class.pluginmedia = pluginmedia_property(new_class)
+        return new_class
+
+
+
 class CMSPluginBase(admin.ModelAdmin):
-    name = ""
-    form = None
     
+    __metaclass__ = PluginMediaDefiningClass # just define a PluginMedia class to add media
+    
+    name = ""
+    
+    form = None
     change_form_template = "admin/cms/page/plugin_change_form.html"
-    admin_preview = True #Should the plugin be rendered in the admin?
+    admin_preview = True # Should the plugin be rendered in the admin?
     
     render_template = None
+    render_plugin = True # Should the plugin be rendered at all, or doesn't it have any output?
     model = CMSPlugin
-    opts = {}
-    placeholders = None # a tupple with placeholder names this plugin can be placed. All if empty
     text_enabled = False
     
+    opts = {}
+    module = None #track in which module/application belongs
+    
     def __init__(self, model=None,  admin_site=None):
         if self.model:
             if not CMSPlugin in self.model._meta.parents and self.model != CMSPlugin:
-                raise SubClassNeededError, "plugin model needs to subclass CMSPlugin"
+                found = False
+                bases = self.model.__bases__
+                while bases:
+                    cls = bases[0]
+                    if cls.__name__ == "CMSPlugin":
+                        found = True
+                        bases = False
+                    else:
+                        bases = cls.__bases__  
+                if not found:
+                    raise SubClassNeededError, "plugin model needs to subclass CMSPlugin"
             if not self.form:
                 class DefaultModelForm(ModelForm):
                     class Meta:
@@ -54,19 +107,24 @@ class CMSPluginBase(admin.ModelAdmin):
         
         self.object_successfully_changed = False
         
-        # variables will be overriden in edit_view, so we got requred
+        # variables will be overwritten in edit_view, so we got required
         self.cms_plugin_instance = None
         self.placeholder = None
-    
-    
+        self.page = None
+
     def render(self, context, instance, placeholder):
         raise NotImplementedError, "render needs to be implemented"
     
+    @property
+    def parent(self):
+        return self.cms_plugin_instance.parent
+    
     def render_change_form(self, request, context, add=False, change=False, form_url='', obj=None):
         """
         We just need the popup interface here
         """
         context.update({
+            'preview': not "no_preview" in request.GET,
             'is_popup': True,
             'plugin': self.cms_plugin_instance,
             'CMS_MEDIA_URL': settings.CMS_MEDIA_URL,
@@ -74,6 +132,9 @@ class CMSPluginBase(admin.ModelAdmin):
         
         return super(CMSPluginBase, self).render_change_form(request, context, add, change, form_url, obj)
     
+    def get_plugin_media(self, request, context, plugin):
+        return self.pluginmedia
+        
     def has_add_permission(self, request, *args, **kwargs):
         """Permission handling change - if user is allowed to change the page
         he must be also allowed to add/change/delete plugins..
@@ -81,14 +142,14 @@ class CMSPluginBase(admin.ModelAdmin):
         Not sure if there will be plugin permission requirement in future, but
         if, then this must be changed.
         """
-        return self.cms_plugin_instance.page.has_change_permission(request)
+        return self.cms_plugin_instance.has_change_permission(request)
     has_delete_permission = has_change_permission = has_add_permission
     
     def save_model(self, request, obj, form, change):
         """
         Override original method, and add some attributes to obj
         This have to be made, because if object is newly created, he must know
-        where he belives.
+        where he lives.
         Attributes from cms_plugin_instance have to be assigned to object, if
         is cms_plugin_instance attribute available.
         """
