@@ -1,5 +1,5 @@
+# -*- coding: utf-8 -*-
 from django.contrib.auth.models import User, Group
-from django.conf import settings
 from django.db.models import Q
 from django.utils.translation import ugettext_lazy as _
 from cms.models import Page, PagePermission, GlobalPagePermission
@@ -63,7 +63,7 @@ def has_page_add_permission(request):
                 return has_generic_permission(page.parent_id, request.user, "add", page.site)
                 #return page.parent.has_add_permission(request)
     else:
-        from cms.admin.utils import current_site
+        from cms.utils.plugins import current_site
         site = current_site(request)
         if (request.user.has_perm(opts.app_label + '.' + opts.get_add_permission()) and
             GlobalPagePermission.objects.with_user(request.user).filter(can_add=True, sites__in=[site])):
@@ -71,7 +71,7 @@ def has_page_add_permission(request):
     return False
 
 def has_any_page_change_permissions(request):
-    from cms.admin.utils import current_site  
+    from cms.utils.plugins import current_site  
     permissions = PagePermission.objects.filter(page__site=current_site(request)).filter(Q(user=request.user)|Q(group__in=request.user.groups.all()))
     if permissions.count()>0:
         return True
@@ -82,7 +82,7 @@ def has_page_change_permission(request):
     just used for building the tree - only superuser, or user with can_change in
     globalpagepermission can change a page.
     """    
-    from cms.admin.utils import current_site    
+    from cms.utils.plugins import current_site    
     opts = Page._meta
     if request.user.is_superuser or \
         (request.user.has_perm(opts.app_label + '.' + opts.get_change_permission()) and
@@ -217,7 +217,7 @@ def mail_page_user_change(user, created=False, password=""):
 
 def has_generic_permission(page_id, user, attr, site):
     """Permission getter for single page with given id.
-    """    
+    """
     func = getattr(Page.permissions, "get_%s_id_list" % attr)
     permission = func(user, site)
     return permission == Page.permissions.GRANT_ALL or page_id in permission
